@@ -3,7 +3,6 @@
 
 Load data using a Reader
 ~~~~~~~~~~~~~~~~~~~~~~~~
-
 """
 
 # sphinx_gallery_start_ignore
@@ -29,7 +28,7 @@ from pyvista import examples
 # An XML PolyData file in ``.vtp`` format is created.  It will be saved in a
 # temporary file for this example.
 
-temp_file = NamedTemporaryFile('w', suffix=".vtp")
+temp_file = NamedTemporaryFile('w', suffix='.vtp')
 temp_file.name
 
 # %%
@@ -45,7 +44,7 @@ mesh.save(temp_file.name)
 # a quick and easy one-liner to read data from files.
 
 new_mesh = pyvista.read(temp_file.name)
-print(f"All arrays: {mesh.array_names}")
+print(f'All arrays: {mesh.array_names}')
 
 # %%
 # Using :func:`pyvista.get_reader` enables more fine-grained control of reading data
@@ -60,10 +59,10 @@ reader
 # data file before loading all the data. For example, we can access the number
 # and names of point and cell arrays.
 
-print(f"Number of point arrays: {reader.number_point_arrays}")
-print(f"Available point data:   {reader.point_array_names}")
-print(f"Number of cell arrays:  {reader.number_cell_arrays}")
-print(f"Available cell data:    {reader.cell_array_names}")
+print(f'Number of point arrays: {reader.number_point_arrays}')
+print(f'Available point data:   {reader.point_array_names}')
+print(f'Number of cell arrays:  {reader.number_cell_arrays}')
+print(f'Available cell data:    {reader.cell_array_names}')
 
 # %%
 # We can select which data to read by selectively disabling or enabling
@@ -73,17 +72,17 @@ print(f"Available cell data:    {reader.cell_array_names}")
 
 reader.disable_all_cell_arrays()
 reader.disable_point_array('Normals')
-print(f"Point array status: {reader.all_point_arrays_status}")
-print(f"Cell array status:  {reader.all_cell_arrays_status}")
+print(f'Point array status: {reader.all_point_arrays_status}')
+print(f'Cell array status:  {reader.all_cell_arrays_status}')
 reader_mesh = reader.read()
-print(f"Read arrays:        {reader_mesh.array_names}")
+print(f'Read arrays:        {reader_mesh.array_names}')
 
 # %%
 # We can reuse the reader object to choose different variables if needed.
 
 reader.enable_all_cell_arrays()
 reader_mesh_2 = reader.read()
-print(f"New read arrays: {reader_mesh_2.array_names}")
+print(f'New read arrays: {reader_mesh_2.array_names}')
 
 # %%
 # Some Readers support setting different time points or iterations. In both
@@ -95,8 +94,8 @@ filename = examples.download_naca(load=False)
 reader = pyvista.get_reader(filename)
 time_values = reader.time_values
 print(reader)
-print(f"Available time points: {time_values}")
-print(f"Available point arrays: {reader.point_array_names}")
+print(f'Available time points: {time_values}')
+print(f'Available point arrays: {reader.point_array_names}')
 
 # %%
 # First both time points are read in, and then the difference in density is
@@ -121,16 +120,16 @@ plotter = pyvista.Plotter(shape='2|1')
 
 plotter.subplot(0)
 plotter.add_mesh(mesh_0, scalars='DENS', show_scalar_bar=False)
-plotter.add_text(f"{time_values[0]}")
+plotter.add_text(f'{time_values[0]}')
 
 plotter.subplot(1)
 plotter.add_mesh(mesh_1, scalars='DENS', show_scalar_bar=False)
-plotter.add_text(f"{time_values[1]}")
+plotter.add_text(f'{time_values[1]}')
 
 # pyvista currently cannot plot the same mesh twice with different scalars
 plotter.subplot(2)
 plotter.add_mesh(mesh_1.copy(), scalars='DENS_DIFF', show_scalar_bar=False)
-plotter.add_text("DENS Difference")
+plotter.add_text('DENS Difference')
 
 plotter.link_views()
 plotter.camera_position = ((0.5, 0, 8), (0.5, 0, 0), (0, 1, 0))
@@ -139,7 +138,7 @@ plotter.show()
 
 # %%
 # Reading time points or iterations can also be utilized to make a movie.
-# Compare to :ref:`gif_movie_example`, but here a set of files are read in
+# Compare to :ref:`gif_example`, but here a set of files are read in
 # through a ParaView Data format file. This file format and reader also return a
 # :class:`pyvista.MultiBlock` mesh.
 
@@ -154,14 +153,16 @@ print(reader)
 
 plotter = pyvista.Plotter(notebook=False, off_screen=True)
 # Open a gif
-plotter.open_gif("wave_pvd.gif")
+plotter.open_gif('wave_pvd.gif')
 
 for time_value in reader.time_values:
     reader.set_active_time_value(time_value)
     mesh = reader.read()[0]  # This dataset only has 1 block
     plotter.add_mesh(mesh, scalars='z', show_scalar_bar=False, lighting=False)
-    plotter.add_text(f"Time: {time_value:.0f}", color="black")
+    plotter.add_text(f'Time: {time_value:.0f}', color='black')
     plotter.write_frame()
     plotter.clear()
 
 plotter.close()
+# %%
+# .. tags:: load
