@@ -125,7 +125,7 @@ conn.plot(
 # First, create a dataset with salient features. Here, we create hills
 # and use curvature to define its peaks and valleys.
 mesh = pv.ParametricRandomHills()
-mesh["Curvature"] = mesh.curvature()
+mesh['Curvature'] = mesh.curvature()
 
 # %%
 # Visualize the peaks and valleys.
@@ -170,3 +170,5 @@ _ = p.add_mesh(peak_mesh, color='red', label='Steepest Peak')
 _ = p.add_mesh(valley_mesh, color='blue', label='Closest Valley')
 _ = p.add_legend()
 p.show()
+# %%
+# .. tags:: filter
