@@ -31,7 +31,7 @@ c = land.geodesic(cape_town, rome)
 # Render the path along the land surface
 
 p = pv.Plotter()
-p.add_mesh(a + b + c, line_width=10, color="red", label="Geodesic Path")
+p.add_mesh(a + b + c, line_width=10, color='red', label='Geodesic Path')
 p.add_mesh(land, show_edges=True)
 p.add_legend()
 p.camera_position = [
@@ -46,3 +46,5 @@ p.show()
 # How long is that path?
 distance = land.geodesic_distance(cape_town, rome)
 distance
+# %%
+# .. tags:: filter
