@@ -4,7 +4,8 @@
 Reflect Meshes
 ~~~~~~~~~~~~~~
 
-This example reflects a mesh across a plane.
+This example reflects a mesh across a plane using
+:meth:`~pyvista.DataObjectFilters.reflect`.
 
 """
 
@@ -30,3 +31,5 @@ p = pyvista.Plotter()
 p.add_mesh(airplane, show_edges=True)
 p.add_mesh(airplane_reflected, show_edges=True)
 p.show()
+# %%
+# .. tags:: filter
