@@ -5,6 +5,8 @@ Create a GIF Movie of a Static Object with a Moving Colormap
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 Generate a gif movie of a Hopf torus with a moving colormap,
 by updating the scalars.
+This example uses :meth:`~pyvista.Plotter.open_gif` and
+:meth:`~pyvista.Plotter.write_frame` to create the gif.
 
 """
 
@@ -56,7 +58,7 @@ mesh = grid.extract_geometry().clean(tolerance=1e-6)
 dists = np.linalg.norm(mesh.points, axis=1)
 dists = 2 * np.pi * (dists - dists.min()) / (dists.max() - dists.min())
 
-mesh["distances"] = np.sin(dists)
+mesh['distances'] = np.sin(dists)
 
 # Make the movie
 pltr = pv.Plotter(window_size=[512, 512])
@@ -64,16 +66,18 @@ pltr.set_focus([0, 0, 0])
 pltr.set_position([40, 0, 0])
 pltr.add_mesh(
     mesh,
-    scalars="distances",
+    scalars='distances',
     smooth_shading=True,
     specular=1,
-    cmap="nipy_spectral",
+    cmap='nipy_spectral',
     show_scalar_bar=False,
 )
-pltr.open_gif("Hopf_torus.gif")
+pltr.open_gif('Hopf_torus.gif')
 
 for t in np.linspace(0, 2 * np.pi, 60, endpoint=False):
-    mesh["distances"] = np.sin(dists - t)
+    mesh['distances'] = np.sin(dists - t)
     pltr.write_frame()
 
 pltr.show()
+# %%
+# .. tags:: plot
