@@ -1,11 +1,11 @@
 """
-.. _plot_opacity_example:
+.. _opacity_example:
 
 Plot with Opacity
 ~~~~~~~~~~~~~~~~~
 
-Plot a mesh's scalar array with an opacity transfer function or opacity mapping
-based on a scalar array.
+Plot a mesh's scalar array with an :class:`~pyvista.opacity_transfer_function`
+or opacity mapping based on a scalar array.
 """
 
 # sphinx_gallery_thumbnail_number = 2
@@ -50,20 +50,26 @@ p.show()
 #
 # Opacity transfer functions are:
 #
-# - ``'linear'``: linearly vary (increase) opacity across the plotted scalar range from low to high
-# - ``'linear_r'``: linearly vary (increase) opacity across the plotted scalar range from high to low
-# - ``'geom'``: on a log scale, vary (increase) opacity across the plotted scalar range from low to high
-# - ``'geom_r'``: on a log scale, vary (increase) opacity across the plotted scalar range from high to low
-# - ``'sigmoid'``: vary (increase) opacity on a sigmoidal s-curve across the plotted scalar range from low to high
-# - ``'sigmoid_r'``: vary (increase) opacity on a sigmoidal s-curve across the plotted scalar range from high to low
+# - ``'linear'``: linearly vary (increase) opacity across the plotted scalar
+#   range from low to high
+# - ``'linear_r'``: linearly vary (increase) opacity across the plotted scalar
+#   range from high to low
+# - ``'geom'``: on a log scale, vary (increase) opacity across the plotted scalar
+#   range from low to high
+# - ``'geom_r'``: on a log scale, vary (increase) opacity across the plotted scalar
+#   range from high to low
+# - ``'sigmoid'``: vary (increase) opacity on a sigmoidal s-curve across the plotted scalar
+#   range from low to high
+# - ``'sigmoid_r'``: vary (increase) opacity on a sigmoidal s-curve across the plotted scalar
+#   range from high to low
 
 # Show the linear opacity transfer function
-mesh.plot(opacity="linear")
+mesh.plot(opacity='linear')
 
 # %%
 
 # Show the sigmoid opacity transfer function
-mesh.plot(opacity="sigmoid")
+mesh.plot(opacity='sigmoid')
 
 # %%
 # It's also possible to use your own transfer function that will be linearly
@@ -74,8 +80,8 @@ opacity = [0, 0.2, 0.9, 0.6, 0.3]
 # %%
 # When given a minimized opacity mapping like that above, PyVista interpolates
 # it across a range of how many colors are shown when mapping the scalars.
-# If ``scipy`` is available, then a quadratic interpolation is used -
-# otherwise, a simple linear interpolation is used.
+# Linear interpolation is used by default, but other kinds of interpolation
+# can be used if ``scipy`` is available.
 # Curious what that opacity transfer function looks like? You can fetch it:
 
 # Have PyVista interpolate the transfer function
@@ -105,19 +111,19 @@ knee = examples.download_knee()
 # And here we inspect the DICOM image with a few different opacity mappings:
 p = pv.Plotter(shape=(2, 2), border=False)
 
-p.add_mesh(knee, cmap="bone", scalar_bar_args={'title': "No Opacity"})
+p.add_mesh(knee, cmap='bone', scalar_bar_args={'title': 'No Opacity'})
 p.view_xy()
 
 p.subplot(0, 1)
-p.add_mesh(knee, cmap="bone", opacity="linear", scalar_bar_args={'title': "Linear Opacity"})
+p.add_mesh(knee, cmap='bone', opacity='linear', scalar_bar_args={'title': 'Linear Opacity'})
 p.view_xy()
 
 p.subplot(1, 0)
-p.add_mesh(knee, cmap="bone", opacity="sigmoid", scalar_bar_args={'title': "Sigmoidal Opacity"})
+p.add_mesh(knee, cmap='bone', opacity='sigmoid', scalar_bar_args={'title': 'Sigmoidal Opacity'})
 p.view_xy()
 
 p.subplot(1, 1)
-p.add_mesh(knee, cmap="bone", opacity="geom_r", scalar_bar_args={'title': "Log Scale Opacity"})
+p.add_mesh(knee, cmap='bone', opacity='geom_r', scalar_bar_args={'title': 'Log Scale Opacity'})
 p.view_xy()
 
 p.show()
@@ -164,3 +170,5 @@ p.subplot(0, 1)
 p.add_text('No Opacity')
 p.add_mesh(contours, scalars='Temperature', cmap='bwr')
 p.show()
+# %%
+# .. tags:: plot
