@@ -4,6 +4,8 @@
 Attenuation
 ~~~~~~~~~~~
 
+This example shows how use :attr:`~pyvista.Light.attenuation_values`.
+
 Attenuation is the phenomenon of light's intensity being gradually dampened as
 it propagates through a medium. In PyVista positional lights can show attenuation.
 The quadratic attenuation model uses three parameters to describe attenuation:
@@ -100,3 +102,5 @@ for attenuation_values, light_x in zip(all_attenuation_values, light_offsets):
 
 plotter.view_vector((1, -2, 2))
 plotter.show()
+# %%
+# .. tags:: lights
