@@ -51,8 +51,6 @@ def __getattr__(name):
         pyvista.utilities.
 
     """
-    from pyvista.core.errors import PyVistaDeprecationWarning
-
     try:
         return globals()[name]
     except KeyError:
@@ -63,11 +61,18 @@ def __getattr__(name):
         if feature is not None:
             break
     else:
-        raise AttributeError(
-            f'Module `pyvista.utilities` has been deprecated and we could not automatically find `{name}`. This feature has moved.',
-        ) from None
+        msg = (
+            f'Module `pyvista.utilities` has been deprecated and we could not automatically '
+            f'find `{name}`. This feature has moved.'
+        )
+        raise AttributeError(msg) from None
 
-    message = f'The `pyvista.utilities` module has been deprecated. `{name}` is now imported as: `{import_path}`.'
+    message = (
+        f'The `pyvista.utilities` module has been deprecated. `{name}` is now imported '
+        f'as: `{import_path}`.'
+    )
+
+    from pyvista.core.errors import PyVistaDeprecationWarning  # noqa: PLC0415
 
     warnings.warn(
         message,
