@@ -14,28 +14,29 @@ import pyvista as pv
 from pyvista import examples
 from pyvista.core.errors import CellSizeError
 from pyvista.core.errors import NotAllTrianglesError
+from pyvista.core.errors import PyVistaDeprecationWarning
 from pyvista.core.errors import PyVistaFutureWarning
 
 radius = 0.5
 
 
-@pytest.fixture()
+@pytest.fixture
 def sphere():
     # this shadows the main sphere fixture from conftest!
-    return pv.Sphere(radius, theta_resolution=10, phi_resolution=10)
+    return pv.Sphere(radius=radius, theta_resolution=10, phi_resolution=10)
 
 
-@pytest.fixture()
+@pytest.fixture
 def sphere_shifted():
     return pv.Sphere(center=[0.5, 0.5, 0.5], theta_resolution=10, phi_resolution=10)
 
 
-@pytest.fixture()
+@pytest.fixture
 def sphere_dense():
-    return pv.Sphere(radius, theta_resolution=100, phi_resolution=100)
+    return pv.Sphere(radius=radius, theta_resolution=100, phi_resolution=100)
 
 
-@pytest.fixture()
+@pytest.fixture
 def cube_dense():
     return pv.Cube()
 
@@ -81,7 +82,7 @@ def test_init_from_arrays(faces_is_cell_array):
     assert not np.allclose(vertices[0], mesh.points[0])
 
     # ensure that polydata raises a warning when inputting non-float dtype
-    with pytest.warns(Warning):
+    with pytest.warns(Warning, match=r'Points is not a float type\. This can cause issues'):
         mesh = pv.PolyData(vertices.astype(np.int32), faces)
 
     # array must be immutable
@@ -96,11 +97,25 @@ def test_init_from_arrays(faces_is_cell_array):
 
 @pytest.mark.parametrize('faces_is_cell_array', [False, True])
 def test_init_from_arrays_with_vert(faces_is_cell_array):
-    vertices = np.array([[0, 0, 0], [1, 0, 0], [1, 1, 0], [0, 1, 0], [0.5, 0.5, -1], [0, 1.5, 1.5]])
+    vertices = np.array(
+        [
+            [0, 0, 0],
+            [1, 0, 0],
+            [1, 1, 0],
+            [0, 1, 0],
+            [0.5, 0.5, -1],
+            [0, 1.5, 1.5],
+        ]
+    )
 
     # mesh faces
     faces = np.hstack(
-        [[4, 0, 1, 2, 3], [3, 0, 1, 4], [3, 1, 2, 4], [1, 5]],  # [quad, triangle, triangle, vertex]
+        [
+            [4, 0, 1, 2, 3],
+            [3, 0, 1, 4],
+            [3, 1, 2, 4],
+            [1, 5],
+        ],  # [quad, triangle, triangle, vertex]
     ).astype(np.int8)
     if faces_is_cell_array:
         faces = pv.CellArray(faces)
@@ -188,24 +203,24 @@ def test_invalid_file():
 
 
 @pytest.mark.parametrize(
-    ("arr", "value"),
+    ('arr', 'value'),
     [
-        ("faces", [3, 1, 2, 3, 3, 0, 1]),
-        ("strips", np.array([5, 4, 3, 2, 0])),
-        ("lines", [4, 0, 1, 2, 2, 3, 4]),
-        ("verts", [1, 0, 1]),
-        ("faces", [[3, 0, 1], [3, 2, 1], [4, 0, 1]]),
-        ("faces", [[2, 0, 1], [2, 2, 1], [1, 0, 1]]),
+        ('faces', [3, 1, 2, 3, 3, 0, 1]),
+        ('strips', np.array([5, 4, 3, 2, 0])),
+        ('lines', [4, 0, 1, 2, 2, 3, 4]),
+        ('verts', [1, 0, 1]),
+        ('faces', [[3, 0, 1], [3, 2, 1], [4, 0, 1]]),
+        ('faces', [[2, 0, 1], [2, 2, 1], [1, 0, 1]]),
     ],
 )
 def test_invalid_connectivity_arrays(arr, value):
     generator = np.random.default_rng(seed=None)
     points = generator.random((10, 3))
     mesh = pv.PolyData(points)
-    with pytest.raises(CellSizeError, match="Cell array size is invalid"):
+    with pytest.raises(CellSizeError, match='Cell array size is invalid'):
         setattr(mesh, arr, value)
 
-    with pytest.raises(CellSizeError, match=f"`{arr}` cell array size is invalid"):
+    with pytest.raises(CellSizeError, match=f'`{arr}` cell array size is invalid'):
         _ = pv.PolyData(points, **{arr: value})
 
 
@@ -284,15 +299,15 @@ def test_geodesic(sphere):
     start, end = 0, sphere.n_points - 1
     geodesic = sphere.geodesic(start, end)
     assert isinstance(geodesic, pv.PolyData)
-    assert "vtkOriginalPointIds" in geodesic.array_names
-    ids = geodesic.point_data["vtkOriginalPointIds"]
+    assert 'vtkOriginalPointIds' in geodesic.array_names
+    ids = geodesic.point_data['vtkOriginalPointIds']
     assert np.allclose(geodesic.points, sphere.points[ids])
 
     # check keep_order
     geodesic_legacy = sphere.geodesic(start, end, keep_order=False)
-    assert geodesic_legacy["vtkOriginalPointIds"][0] == end
+    assert geodesic_legacy['vtkOriginalPointIds'][0] == end
     geodesic_ordered = sphere.geodesic(start, end, keep_order=True)
-    assert geodesic_ordered["vtkOriginalPointIds"][0] == start
+    assert geodesic_ordered['vtkOriginalPointIds'][0] == start
 
     # finally, inplace
     geodesic_inplace = sphere.geodesic(start, end, inplace=True)
@@ -340,7 +355,7 @@ def test_ray_trace_origin():
 def test_multi_ray_trace(sphere):
     trimesh = pytest.importorskip('trimesh')
     if not trimesh.ray.has_embree:
-        pytest.skip("Requires Embree")
+        pytest.skip('Requires Embree')
     origins = [[1, 0, 1], [0.5, 0, 1], [0.25, 0, 1], [0, 0, 5]]
     directions = [[0, 0, -1]] * 4
     points, ind_r, ind_t = sphere.multi_ray_trace(origins, directions)
@@ -386,6 +401,19 @@ def test_boolean_union_intersection(sphere, sphere_shifted):
     assert np.isclose(intersection.volume, expected_volume, atol=1e-3)
 
 
+def test_bitwise_and_or(sphere, sphere_shifted):
+    union = sphere | sphere_shifted
+    intersection = sphere & sphere_shifted
+
+    # union is volume of sphere + sphere_shifted minus the part intersecting
+    expected_volume = sphere.volume + sphere_shifted.volume - intersection.volume
+    assert np.isclose(union.volume, expected_volume, atol=1e-3)
+
+    # intersection volume is the volume of both isolated meshes minus the union
+    expected_volume = sphere.volume + sphere_shifted.volume - union.volume
+    assert np.isclose(intersection.volume, expected_volume, atol=1e-3)
+
+
 def test_boolean_difference(sphere, sphere_shifted):
     difference = sphere.boolean_difference(sphere_shifted, progress_bar=True)
     intersection = sphere.boolean_intersection(sphere_shifted, progress_bar=True)
@@ -404,6 +432,12 @@ def test_subtract(sphere, sphere_shifted):
     assert sub_mesh.n_points == sphere.boolean_difference(sphere_shifted).n_points
 
 
+def test_isubtract(sphere, sphere_shifted):
+    sub_mesh = sphere.copy()
+    sub_mesh -= sphere_shifted
+    assert sub_mesh.n_points == sphere.boolean_difference(sphere_shifted).n_points
+
+
 def test_append(
     sphere: pv.PolyData,
     sphere_shifted: pv.PolyData,
@@ -434,7 +468,7 @@ def test_append(
 
 
 def test_append_raises(sphere: pv.PolyData):
-    with pytest.raises(TypeError, match="All meshes need to be of PolyData type"):
+    with pytest.raises(TypeError, match='All meshes need to be of PolyData type'):
         sphere.append_polydata(sphere.cast_to_unstructured_grid())
 
 
@@ -475,8 +509,12 @@ def test_merge(sphere, sphere_shifted, hexbeam):
     assert merged.active_scalars_name is None
 
     # test merge with lines
-    arc_1 = pv.CircularArc([0, 0, 0], [10, 10, 0], [10, 0, 0], negative=False, resolution=3)
-    arc_2 = pv.CircularArc([10, 10, 0], [20, 0, 0], [10, 0, 0], negative=False, resolution=3)
+    arc_1 = pv.CircularArc(
+        pointa=[0, 0, 0], pointb=[10, 10, 0], center=[10, 0, 0], negative=False, resolution=3
+    )
+    arc_2 = pv.CircularArc(
+        pointa=[10, 10, 0], pointb=[20, 0, 0], center=[10, 0, 0], negative=False, resolution=3
+    )
     merged = arc_1 + arc_2
     assert merged.n_lines == 2
     assert merged.active_scalars_name == 'Distance'
@@ -530,8 +568,11 @@ def test_merge_active_scalars(input_):
     assert merged.active_scalars_name == 'foo'
 
 
-@pytest.mark.parametrize('input_', [examples.load_hexbeam(), pv.Sphere()])
-def test_merge_main_has_priority(input_):
+@pytest.mark.parametrize(
+    'input_', [examples.load_hexbeam(), pv.Plane(i_resolution=1, j_resolution=1)]
+)
+@pytest.mark.parametrize('main_has_priority', [True, False])
+def test_merge_main_has_priority(input_, main_has_priority):
     mesh = input_.copy()
     data_main = np.arange(mesh.n_points, dtype=float)
     mesh.point_data['present_in_both'] = data_main
@@ -551,13 +592,61 @@ def test_merge_main_has_priority(input_):
             for j in (this.points == point).all(-1).nonzero()
         )
 
-    merged = mesh.merge(other, main_has_priority=True)
-    assert matching_point_data(merged, mesh, 'present_in_both')
+    if pv.vtk_version_info >= (9, 5, 0):
+        merged = mesh.merge(other)
+        expected_to_match = mesh
+    else:
+        with pytest.warns(
+            pv.PyVistaDeprecationWarning,
+            match="The keyword 'main_has_priority' is deprecated and should not be used",
+        ):
+            merged = mesh.merge(other, main_has_priority=main_has_priority)
+        expected_to_match = mesh if main_has_priority else other
+    assert matching_point_data(merged, expected_to_match, 'present_in_both')
     assert merged.active_scalars_name == 'present_in_both'
 
-    merged = mesh.merge(other, main_has_priority=False)
-    assert matching_point_data(merged, other, 'present_in_both')
-    assert merged.active_scalars_name == 'present_in_both'
+
+@pytest.mark.parametrize('main_has_priority', [True, False])
+def test_merge_main_has_priority_deprecated(sphere, main_has_priority):
+    match = (
+        "The keyword 'main_has_priority' is deprecated and should not be used.\n"
+        'The main mesh will always have priority in a future version.'
+    )
+    if main_has_priority is False and pv.vtk_version_info >= (9, 5, 0):
+        with pytest.raises(ValueError, match=match):
+            sphere.merge(sphere, main_has_priority=main_has_priority)
+    else:
+        with pytest.warns(pv.PyVistaDeprecationWarning, match=match):
+            sphere.merge(sphere, main_has_priority=main_has_priority)
+
+
+@pytest.mark.parametrize('main_has_priority', [True, False])
+@pytest.mark.parametrize('mesh', [pv.UnstructuredGrid(), pv.PolyData()])
+def test_merge_field_data(mesh, main_has_priority):
+    key = 'data'
+    data_main = [1, 2, 3]
+    data_other = [4, 5, 6]
+    mesh.field_data[key] = data_main
+    other = mesh.copy()
+    other.field_data[key] = data_other
+
+    match = (
+        "The keyword 'main_has_priority' is deprecated and should not be used.\n"
+        'The main mesh will always have priority in a future version, and this '
+        'keyword will be removed.'
+    )
+    if main_has_priority is False and pv.vtk_version_info >= (9, 5, 0):
+        match += '\nIts value cannot be False for vtk>=9.5.0.'
+        with pytest.raises(ValueError, match=re.escape(match)):
+            mesh.merge(other, main_has_priority=main_has_priority)
+        return
+    else:
+        with pytest.warns(pv.PyVistaDeprecationWarning, match=match):
+            merged = mesh.merge(other, main_has_priority=main_has_priority)
+
+    actual = merged.field_data[key]
+    expected = data_main if main_has_priority else data_other
+    assert np.array_equal(actual, expected)
 
 
 def test_add(sphere, sphere_shifted):
@@ -605,9 +694,14 @@ def test_invalid_curvature(sphere):
 @pytest.mark.parametrize('binary', [True, False])
 @pytest.mark.parametrize('extension', pv.core.pointset.PolyData._WRITERS)
 def test_save(sphere, extension, binary, tmpdir):
-    filename = str(tmpdir.mkdir("tmpdir").join(f'tmp{extension}'))
-    sphere.save(filename, binary)
+    filename = str(tmpdir.mkdir('tmpdir').join(f'tmp{extension}'))
 
+    if extension == '.vtkhdf' and not binary:
+        with pytest.raises(ValueError, match='.vtkhdf files can only be written in binary format'):
+            sphere.save(filename, binary=binary)
+        return
+
+    sphere.save(filename, binary=binary)
     if binary:
         if extension == '.vtp':
             with Path(filename).open() as f:
@@ -633,7 +727,7 @@ def test_save(sphere, extension, binary, tmpdir):
 
 
 def test_pathlib_read_write(tmpdir, sphere):
-    path = pathlib.Path(str(tmpdir.mkdir("tmpdir").join('tmp.vtk')))
+    path = pathlib.Path(str(tmpdir.mkdir('tmpdir').join('tmp.vtk')))
     sphere.save(path)
     assert path.is_file()
 
@@ -662,6 +756,24 @@ def test_triangulate_filter(plane):
     assert not plane.extract_all_edges().is_all_triangles
 
 
+@pytest.mark.parametrize('pass_lines', [True, False])
+def test_triangulate_filter_pass_lines(sphere: pv.PolyData, plane: pv.PolyData, pass_lines: bool):
+    merge: pv.PolyData = plane + (lines := sphere.extract_all_edges())
+    tri: pv.PolyData = merge.triangulate(pass_lines=pass_lines, inplace=False)
+
+    assert tri.n_lines == (lines.n_cells if pass_lines else 0)
+    assert tri.is_all_triangles if not pass_lines else (not tri.is_all_triangles)
+
+
+@pytest.mark.parametrize('pass_verts', [True, False])
+def test_triangulate_filter_pass_verts(plane: pv.PolyData, pass_verts: bool):
+    merge: pv.PolyData = plane + (verts := pv.PolyData([0.0, 1.0, 2.0]))
+    tri: pv.PolyData = merge.triangulate(pass_verts=pass_verts, inplace=False)
+
+    assert tri.n_verts == (verts.n_cells if pass_verts else 0)
+    assert tri.is_all_triangles if not pass_verts else (not tri.is_all_triangles)
+
+
 @pytest.mark.parametrize('subfilter', ['butterfly', 'loop', 'linear'])
 def test_subdivision(sphere, subfilter):
     mesh = sphere.subdivide(1, subfilter, progress_bar=True)
@@ -744,8 +856,8 @@ def test_compute_normals(sphere):
 
 def test_compute_normals_raises(sphere):
     msg = (
-        'Normals cannot be computed for PolyData containing only vertex cells (e.g. point clouds)\n'
-        'and/or line cells. The PolyData cells must be polygons (e.g. triangle cells).'
+        'Normals cannot be computed for PolyData containing only vertex cells (e.g. point clouds)'
+        '\nand/or line cells. The PolyData cells must be polygons (e.g. triangle cells).'
     )
 
     point_cloud = pv.PolyData(sphere.points)
@@ -786,7 +898,7 @@ def test_compute_normals_split_vertices(cube):
     assert len(set(cube_split_norm.point_data['pyvistaOriginalPointIds'])) == 8
 
 
-@pytest.fixture()
+@pytest.fixture
 def ant_with_normals(ant):
     ant['Scalars'] = range(ant.n_points)
     point_normals = [[0, 0, 1]] * ant.n_points
@@ -857,13 +969,19 @@ def test_clip_plane(sphere):
     faces = clipped_sphere.faces.reshape(-1, 4)[:, 1:]
     assert np.all(clipped_sphere.points[faces, 2] <= 0)
 
-    sphere.clip(origin=[0, 0, 0], normal=[0, 0, -1], inplace=True, invert=False, progress_bar=True)
+    sphere.clip(
+        origin=[0, 0, 0],
+        normal=[0, 0, -1],
+        inplace=True,
+        invert=False,
+        progress_bar=True,
+    )
     faces = clipped_sphere.faces.reshape(-1, 4)[:, 1:]
     assert np.all(clipped_sphere.points[faces, 2] <= 0)
 
 
 def test_extract_largest(sphere):
-    mesh = sphere + pv.Sphere(0.1, theta_resolution=5, phi_resolution=5)
+    mesh = sphere + pv.Sphere(radius=0.1, theta_resolution=5, phi_resolution=5)
     largest = mesh.extract_largest()
     assert largest.n_faces_strict == sphere.n_faces_strict
 
@@ -937,7 +1055,7 @@ def test_remove_points_fail(sphere, plane):
 
 def test_vertice_cells_on_read(tmpdir):
     point_cloud = pv.PolyData(np.random.default_rng().random((100, 3)))
-    filename = str(tmpdir.mkdir("tmpdir").join('foo.ply'))
+    filename = str(tmpdir.mkdir('tmpdir').join('foo.ply'))
     point_cloud.save(filename)
     recovered = pv.read(filename)
     assert recovered.n_cells == 100
@@ -950,7 +1068,7 @@ def test_center_of_mass(sphere):
     cloud = pv.PolyData(np.random.default_rng().random((100, 3)))
     assert len(cloud.center_of_mass()) == 3
     cloud['weights'] = np.random.default_rng().random(cloud.n_points)
-    center = cloud.center_of_mass(True)
+    center = cloud.center_of_mass(scalars_weight=True)
     assert len(center) == 3
 
 
@@ -1093,7 +1211,13 @@ def test_is_all_triangles():
     vertices = np.array([[0, 0, 0], [1, 0, 0], [1, 1, 0], [0, 1, 0], [0.5, 0.5, -1]])
 
     # mesh faces
-    faces = np.hstack([[4, 0, 1, 2, 3], [3, 0, 1, 4], [3, 1, 2, 4]])  # [square, triangle, triangle]
+    faces = np.hstack(
+        [
+            [4, 0, 1, 2, 3],
+            [3, 0, 1, 4],
+            [3, 1, 2, 4],
+        ]
+    )  # [square, triangle, triangle]
 
     mesh = pv.PolyData(vertices, faces)
     assert not mesh.is_all_triangles
@@ -1102,7 +1226,7 @@ def test_is_all_triangles():
 
 
 def test_extrude():
-    arc = pv.CircularArc([-1, 0, 0], [1, 0, 0], [0, 0, 0])
+    arc = pv.CircularArc(pointa=[-1, 0, 0], pointb=[1, 0, 0], center=[0, 0, 0])
     poly = arc.extrude([0, 0, 1], progress_bar=True, capping=True)
     assert poly.n_points
     assert poly.n_cells
@@ -1114,24 +1238,48 @@ def test_extrude():
 
 
 def test_extrude_capping_warnings():
-    arc = pv.CircularArc([-1, 0, 0], [1, 0, 0], [0, 0, 0])
+    arc = pv.CircularArc(pointa=[-1, 0, 0], pointb=[1, 0, 0], center=[0, 0, 0])
     with pytest.warns(PyVistaFutureWarning, match='default value of the ``capping`` keyword'):
         arc.extrude([0, 0, 1])
     with pytest.warns(PyVistaFutureWarning, match='default value of the ``capping`` keyword'):
         arc.extrude_rotate()
 
 
-def test_flip_normals(sphere, plane):
-    sphere_flipped = sphere.copy()
-    sphere_flipped.flip_normals()
+def test_flip_normals(sphere):
+    with pytest.warns(
+        PyVistaDeprecationWarning, match='`flip_normals` is deprecated. Use `flip_faces` instead'
+    ):
+        sphere.flip_normals()
 
-    sphere.compute_normals(inplace=True)
-    sphere_flipped.compute_normals(inplace=True)
-    assert np.allclose(sphere_flipped.point_data['Normals'], -sphere.point_data['Normals'])
 
-    # invalid case
-    with pytest.raises(NotAllTrianglesError):
-        plane.flip_normals()
+@pytest.mark.parametrize('mesh', [pv.Sphere(), pv.Plane()])
+def test_flip_normal_vectors(mesh):
+    mesh = mesh.compute_normals()
+    flipped = mesh.flip_normal_vectors(inplace=True, progress_bar=True)
+    assert flipped is mesh
+
+    flipped = mesh.flip_normal_vectors()
+    assert flipped is not mesh
+
+    assert np.allclose(flipped.point_data['Normals'], -mesh.point_data['Normals'])
+    assert np.allclose(flipped.cell_data['Normals'], -mesh.cell_data['Normals'])
+
+    # Test ordering is unaffected
+    assert np.allclose(flipped.faces, mesh.faces)
+
+
+@pytest.mark.parametrize('mesh', [pv.Sphere(), pv.Plane()])
+def test_flip_faces(mesh):
+    flipped = mesh.flip_faces(inplace=True, progress_bar=True)
+    assert flipped is mesh
+
+    flipped = mesh.flip_faces()
+    assert flipped is not mesh
+
+    assert np.allclose(flipped.regular_faces[0], mesh.regular_faces[0][::-1])
+
+    # Test normals are unaffected
+    assert np.allclose(flipped.point_data['Normals'], mesh.point_data['Normals'])
 
 
 def test_n_verts():
@@ -1155,44 +1303,59 @@ def test_n_faces_strict():
     assert mesh.n_faces_strict == 1
 
 
-@pytest.fixture()
-def default_n_faces():  # noqa: PT004
-    pv.PolyData._WARNED_DEPRECATED_NONSTRICT_N_FACES = False
+@pytest.fixture
+def default_n_faces():
     pv.PolyData._USE_STRICT_N_FACES = False
     yield
-    pv.PolyData._WARNED_DEPRECATED_NONSTRICT_N_FACES = False
     pv.PolyData._USE_STRICT_N_FACES = False
 
 
-def test_n_faces(default_n_faces):
-    if pv._version.version_info >= (0, 46):
-        raise RuntimeError("Convert non-strict n_faces use to error")
+def test_n_faces():
+    if pv._version.version_info[:2] >= (0, 46):
+        # At version 0.46, n_faces should raise an error instead of warning
+        mesh = pv.PolyData(
+            [(0.0, 0.0, 0.0), (1.0, 0.0, 0.0), (0.0, 1.0, 0.0)],
+            faces=[3, 0, 1, 2],
+            lines=[2, 0, 1],
+        )
 
-    if pv._version.version_info >= (0, 49):
-        raise RuntimeError("Convert default n_faces behavior to strict")
+        # Should raise an AttributeError
+        with pytest.raises(
+            AttributeError,
+            match='The non-strict behavior of `pv.PolyData.n_faces` has been removed',
+        ):
+            _ = mesh.n_faces
+    else:
+        # Pre-0.46 behavior: warning
+        mesh = pv.PolyData(
+            [(0.0, 0.0, 0.0), (1.0, 0.0, 0.0), (0.0, 1.0, 0.0)],
+            faces=[3, 0, 1, 2],
+            lines=[2, 0, 1],
+        )
 
-    mesh = pv.PolyData(
-        [(0.0, 0.0, 0.0), (1.0, 0.0, 0.0), (0.0, 1.0, 0.0)],
-        faces=[3, 0, 1, 2],
-        lines=[2, 0, 1],
-    )
+        # Should raise a warning the first time
+        with pytest.warns(
+            pv.PyVistaDeprecationWarning,
+            match='The current behavior of `pv.PolyData.n_faces` has been deprecated',
+        ):
+            nf = mesh.n_faces
 
-    # Should raise a warning the first time
-    with pytest.warns(pv.PyVistaDeprecationWarning):
-        nf = mesh.n_faces
+        # Current (deprecated) behavior is that n_faces is aliased to n_cells
+        assert nf == mesh.n_cells
 
-    # Current (deprecated) behavior is that n_faces is aliased to n_cells
-    assert nf == mesh.n_cells
+        # Shouldn't raise deprecation warning the second time
+        with warnings.catch_warnings():
+            warnings.simplefilter('error')
+            nf1 = mesh.n_faces
 
-    # Shouldn't raise deprecation warning the second time
-    with warnings.catch_warnings():
-        warnings.simplefilter("error")
-        nf1 = mesh.n_faces
+        assert nf1 == nf
 
-    assert nf1 == nf
+    if pv._version.version_info[:2] > (0, 49):
+        msg = 'Convert default n_faces behavior to strict'
+        raise RuntimeError(msg)
 
 
-def test_opt_in_n_faces_strict(default_n_faces):
+def test_opt_in_n_faces_strict():
     pv.PolyData.use_strict_n_faces(True)
     mesh = pv.PolyData(
         [(0.0, 0.0, 0.0), (1.0, 0.0, 0.0), (0.0, 1.0, 0.0)],
@@ -1207,7 +1370,7 @@ def test_geodesic_disconnected(sphere, sphere_shifted):
     combined = sphere + sphere_shifted
     start_vertex = 0
     end_vertex = combined.n_points - 1
-    match = f"There is no path between vertices {start_vertex} and {end_vertex}."
+    match = f'There is no path between vertices {start_vertex} and {end_vertex}.'
 
     with pytest.raises(ValueError, match=match):
         combined.geodesic(start_vertex, end_vertex)
@@ -1253,7 +1416,7 @@ def test_regular_faces_mutable():
 
 def _assert_irregular_faces_equal(faces, expected):
     assert len(faces) == len(expected)
-    assert all(np.array_equal(a, b) for (a, b) in zip(faces, expected))
+    assert all(map(np.array_equal, faces, expected))
 
 
 def test_irregular_faces():
@@ -1290,9 +1453,24 @@ def test_irregular_faces_mutable():
 def test_n_faces_etc_deprecated(cells: str):
     n_cells = 'n_' + cells
     kwargs = {cells: [3, 0, 1, 2], n_cells: 1}  # e.g. specify faces and n_faces
-    with pytest.warns(pv.PyVistaDeprecationWarning):
+    with pytest.warns(
+        pv.PyVistaDeprecationWarning,
+        match=f'`PolyData` constructor parameter `{n_cells}` is deprecated and no longer used',
+    ):
         _ = pv.PolyData(np.zeros((3, 3)), **kwargs)
-        if pv._version.version_info >= (0, 47):
-            raise RuntimeError(f"Convert `PolyData` `{n_cells}` deprecation warning to error")
-        if pv._version.version_info >= (0, 48):
-            raise RuntimeError(f"Remove `PolyData` `{n_cells} constructor kwarg")
+    if pv._version.version_info[:2] > (0, 47):
+        msg = f'Convert `PolyData` `{n_cells}` deprecation warning to error'
+        raise RuntimeError(msg)
+    if pv._version.version_info[:2] > (0, 48):
+        msg = f'Remove `PolyData` `{n_cells} constructor kwarg'
+        raise RuntimeError(msg)
+
+
+@pytest.mark.parametrize('inplace', [True, False])
+def test_merge_points(inplace):
+    mesh = pv.Cylinder(resolution=4)
+    assert mesh.n_points == 8 * 2
+    output = mesh.merge_points(inplace=inplace)
+    assert output.n_points == 8
+    assert isinstance(mesh, pv.PolyData)
+    assert (mesh is output) == inplace
