@@ -13,7 +13,6 @@ import pyvista as pv
 from pyvista.plotting import system_supports_plotting
 
 # these are set here because we only need them for plotting tests
-pv.global_theme.load_theme(pv.plotting.themes._TestingTheme())
 pv.OFF_SCREEN = True
 SKIP_PLOTTING = not system_supports_plotting()
 
@@ -35,33 +34,21 @@ def pytest_runtest_setup(item):
 def _is_vtk(obj):
     try:
         return obj.__class__.__name__.startswith('vtk')
-    except Exception:  # old Python sometimes no __class__.__name__
+    except (ReferenceError, AttributeError):
         return False
 
 
-@pytest.fixture()
-def skip_check_gc(check_gc):  # noqa: PT004
-    """Skip check_gc fixture."""
-    check_gc.skip = True
-
-
 @pytest.fixture(autouse=True)
-def check_gc():
+def check_gc(request):
     """Ensure that all VTK objects are garbage-collected by Python."""
+    if request.node.get_closest_marker('skip_check_gc'):
+        yield
+        return
+
     gc.collect()
     before = {id(o) for o in gc.get_objects() if _is_vtk(o)}
 
-    class GcHandler:
-        def __init__(self) -> None:
-            # if set to True, will entirely skip checking in this fixture
-            self.skip = False
-
-    gc_handler = GcHandler()
-
-    yield gc_handler
-
-    if gc_handler.skip:
-        return
+    yield
 
     pv.close_all()
 
@@ -95,13 +82,21 @@ def check_gc():
     assert len(after) == 0, msg
 
 
-@pytest.fixture()
+@pytest.fixture
 def colorful_tetrahedron():
     mesh = pv.Tetrahedron()
-    mesh.cell_data["colors"] = [[255, 255, 255], [255, 0, 0], [0, 255, 0], [0, 0, 255]]
+    mesh.cell_data['colors'] = [[255, 255, 255], [255, 0, 0], [0, 255, 0], [0, 0, 255]]
     return mesh
 
 
+@pytest.fixture(autouse=True)
+def set_default_theme():
+    """Reset the testing theme for every test."""
+    pv.global_theme.load_theme(pv.plotting.themes._TestingTheme())
+    yield
+    pv.global_theme.load_theme(pv.plotting.themes._TestingTheme())
+
+
 def make_two_char_img(text):
     """Turn text into an image.
 
@@ -117,8 +112,8 @@ def make_two_char_img(text):
     return pv.Texture(pl.screenshot()).to_image()
 
 
-@pytest.fixture()
-def cubemap(texture):
+@pytest.fixture
+def cubemap():
     """Sample texture as a cubemap."""
     return pv.Texture(
         [
